<?php

use EventPortal\Http\Controllers\Admin\Delegate\DelegateController;
use EventPortal\Http\Controllers\Admin\Event\ArchivedEventController;
use EventPortal\Http\Controllers\Admin\Event\EventController;
use EventPortal\Http\Controllers\Admin\EventDelegate\DelegatesNotOnEventController;
use EventPortal\Http\Controllers\Admin\EventDelegate\EventDelegateController;
use EventPortal\Http\Controllers\Admin\TeamController;
use Illuminate\Support\Facades\Route;

Route::get('/', 'DashboardController')->name('admin.dashboard.index');

Route::group(['prefix' => 'events'], static function (): void {
    Route::group(['prefix' => '{event}/delegates'], static function (): void {
        Route::get('/add', [DelegatesNotOnEventController::class, 'index'])->name('admin.event.delegate.create');
        Route::post('/add', 'EventDelegate\AssociateToEventController')->name('admin.event.delegate.store');
        Route::post('/remote', 'EventDelegate\DisassociateFromEventController')->name('admin.event.delegate.destroy');

        Route::get('/', [EventDelegateController::class, 'index'])->name('admin.event.delegate.index');
        Route::get('{delegate}', [EventDelegateController::class, 'show'])->name('admin.event.delegate.show');
        Route::post(
            '{delegate}/transition/{type}',
            'EventDelegate\EventDelegateTransitionController'
        )->name('admin.event.delegate.transition');
    });

    Route::get('/archived', [ArchivedEventController::class, 'index'])->name('admin.archived-event.index');

    Route::post('{event}/transition/{type}', 'Event\EventTransitionController')->name('admin.event.transition');

    Route::get('/', [EventController::class, 'index'])->name('admin.event.index');
    Route::post('/', [EventController::class, 'store'])->name('admin.event.store');

    Route::get('create', [EventController::class, 'create'])->name('admin.event.create');
    Route::prefix('{event}')->middleware('current-team')->group(static function (): void {
        Route::get('/', [EventController::class, 'show'])->name('admin.event.show');
        Route::get('/edit', [EventController::class, 'edit'])->name('admin.event.edit');
        Route::post('/update', [EventController::class, 'update'])->name('admin.event.update');
        Route::post('/delete', [EventController::class, 'delete'])->name('admin.event.delete');
    });
});

Route::group(['prefix' => 'permissions'], function (): void {
    Route::get('/', 'PermissionController@index')->name('admin.permission.index');
    Route::post('/', 'PermissionController@update')->name('admin.permission.update');
});

Route::post('user-type/', 'RoleController@store')->name('admin.role.store');

Route::group(['prefix' => 'delegate'], function (): void {
    Route::get('/', [DelegateController::class, 'index'])->name('admin.delegate.index');
    Route::get('create', [DelegateController::class, 'create'])->name('admin.delegate.create');
    Route::post('/', [DelegateController::class, 'store'])->name('admin.delegate.store');
    Route::get('{delegate}/edit', [DelegateController::class, 'edit'])->name('admin.delegate.edit');
    Route::post('{delegate}/update', [DelegateController::class, 'update'])->name('admin.delegate.update');
    Route::get('{delegate}', [DelegateController::class, 'show'])->name('admin.delegate.show');
});

Route::group(['prefix' => 'team'], static function (): void {
    Route::get('/', [TeamController::class, 'index'])->name('admin.team.index');
    Route::post('/', [TeamController::class, 'store'])->name('admin.team.store');
    Route::get('create', [TeamController::class, 'create'])->name('admin.team.create');
    Route::get('{team}/edit', [TeamController::class, 'edit'])->name('admin.team.edit');
    Route::post('{team}/update', [TeamController::class, 'update'])->name('admin.team.update');
    Route::post('{team}/delete', [TeamController::class, 'delete'])->name('admin.team.delete');
});

Route::group(['prefix' => 'user'], function (): void {
    Route::get('/', 'UserController@index')->name('admin.user.index');
    Route::get('create', 'UserController@create')->name('admin.user.create');
    Route::post('/', 'UserController@store')->name('admin.user.store');

    Route::prefix('{admin}')->group(function (): void {
        Route::get('/', 'UserController@show')->name('admin.user.show');
        Route::get('edit', 'UserController@edit')->name('admin.user.edit');
        Route::post('update', 'UserController@update')->name('admin.user.update');
        Route::post('delete', 'UserController@delete')->name('admin.user.delete');
    });
});
