<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Domain\Team\TeamListing;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use EventPortal\Http\Requests\TeamRequest;
use Illuminate\Http\RedirectResponse;
use Inertia\Inertia;
use Inertia\Response;

class TeamController extends Controller
{
    public function index(): Response
    {
        $table = Table::make('team.index')
            ->query(Team::query())
            ->request(request())
            ->get();

        return Inertia::render('Team/Index', [
            'data' => $table,
        ]);
    }

    public function create(): Response
    {
        $admins = Admin::all()->mapInto(TeamListing::class);

        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add('Create a team')
            ->get();

        return Inertia::render('Team/Create', [
            'breadcrumbs' => $breadcrumbs,
            'allUsers' => $admins,
        ]);
    }

    public function store(TeamRequest $request): RedirectResponse
    {
        $team = Team::create($request->only([
            'name',
            'description',
        ]));

        $team->admins()->attach($request->input('members'));

        return redirect()->route('admin.team.index');
    }

    public function edit(Team $team): Response
    {
        $teamUsers = $team->admins()->get();

        $allUsers = Admin::query()
            ->whereNotIn('user_id', $teamUsers->pluck('id'))
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add($team->name, route('admin.team.edit', $team))
            ->get();

        return Inertia::render('Team/Edit', [
            'teamName' => $team->name,
            'teamId' => $team->id,
            'breadcrumbs' => $breadcrumbs,
            'allUsers' => $allUsers->mapInto(TeamListing::class)->values()->toArray(),
            'teamUsers' => $teamUsers->mapInto(TeamListing::class)->values()->toArray(),
        ]);
    }

    public function update(TeamRequest $request, Team $team): RedirectResponse
    {
        $team->update($request->only([
            'slug',
            'name',
            'description',
        ]));

        $team->admins()->sync($request->input('members'));

        return redirect()->route('admin.team.index');
    }
}
